@@ -1,37 +1,22 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright (C) 2014  Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
- *
- */
+    SPDX-FileCopyrightText: 2014 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
 
 #include "filefetchjob.h"
 #include "filemetadatautil_p.h"
 #include "widgetsdebug.h"
 
+#include <Baloo/File>
 #include <QFileInfo>
 #include <QTimer>
-#include <Baloo/File>
 
 #include <KFileMetaData/UserMetaData>
 
 using namespace Baloo;
 
-FileFetchJob::FileFetchJob(const QStringList& urls, bool canEditAll,
-    FileFetchJob::UseRealtimeIndexing useRealtime, QObject* parent)
+FileFetchJob::FileFetchJob(const QStringList &urls, bool canEditAll, FileFetchJob::UseRealtimeIndexing useRealtime, QObject *parent)
     : KJob(parent)
     , m_urls(urls)
     , m_canEditAll(canEditAll)
@@ -46,8 +31,7 @@ void FileFetchJob::start()
 
 void FileFetchJob::doStart()
 {
-    for (const QString& filePath : m_urls) {
-
+    for (const QString &filePath : qAsConst(m_urls)) {
         bool extractorRunning = false;
         KFileMetaData::PropertyMap fileProperties;
 
@@ -90,7 +74,7 @@ void FileFetchJob::doStart()
     emitResult();
 }
 
-QList<QVariantMap>  Baloo::FileFetchJob::data() const
+QList<QVariantMap> Baloo::FileFetchJob::data() const
 {
     return m_data;
 }
